#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

from lxml import etree as ET


def dict2xml(a, root_name, output_file="cep.xml"):
    def _iter(l, result):
        if isinstance(l, dict):
            for key in l.keys():
                k = ET.SubElement(result, key)
                z = _iter(l[key], k)
                if z is None:
                    continue
                k.text = str(z)
        elif isinstance(l, list):
            for v in l:
                if len(v) == 1:
                    k = ET.SubElement(result, v.keys()[0])
                    z = _iter(v[v.keys()[0]], k)
                else:
                    k = ET.SubElement(result, v["XmlLabel"])
                    v.pop("XmlLabel", None)
                    z = _iter(v, k)
                if z is None:
                    continue
                k.text = str(z)

        else:
            return l

    r = ET.Element(root_name)
    _iter(a, r)
    with open(output_file, "w") as f:
        z = ET.ElementTree(r)
        z.write(f, pretty_print=True)


if __name__ == "__main__":
    pass
