#!/usr/bin/env python
#
# Copyright (c) 2016-2017, Parallels International GmbH
#
# This file is part of disp-helper. It's free software; you can redistribute
# it and/or modify it under the terms of the GNU General Public License as
# published by the Free Software Foundation; either version 2 of the License,
# or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful, but
# WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
# General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
# 02110-1301, USA.
#
# Our contact details: Parallels International GmbH, Vordergasse 59, 8200
# Schaffhausen, Switzerland.
#

import json
import os
import re
import time
from infra_cep_helper import CEPCollecting


class VEs(CEPCollecting):
    def get_ct_packages(self, uuid):
        out = self.execute_shell("/usr/sbin/vzpkg list " + uuid + " -qp")
        l = list()
        for pkg in out.splitlines():
            l.insert(0, "-".join(pkg.split()))
        return l

    def fill_results(self):
        retries = 0
        succeed = False
        fail_reason = "Unknown reason"
        r = re.compile("^([^=\#]+)=([^\#]*)$")
        while not succeed and retries < 4:
            try:
                cmd = "/usr/bin/prlctl list -ai --full --json"
                out = self.execute_shell(cmd)
                ves = json.loads(out)
                for ve in ves:
                    if "Type" in ve and ve["Type"] == "CT":
                        ve["Packages"] = self.get_ct_packages(ve["EnvID"])
                        l = list()
                        home_path = os.path.join(ve["Home"], "ve.conf")
                        with open(home_path, "r") as f:
                            for line in f.readlines():
                                try:
                                    (name, value) = re.findall(r, line.strip())[0]
                                    l.insert(0, {name: value.strip("\"")})
                                except:
                                    continue
                        ve["CtConfig"] = l
                    self.prepare_tags(ve)

                    ve["XmlLabel"] = "VE"
                self.result["VEs"] = ves
                cmd = "/usr/bin/vzps faxh -octid,cmd"
                x = []
                regex = re.compile("^\s*0\s")
                out = self.execute_shell(cmd)
                for line in out.splitlines():
                    if regex.match(line):
                        continue
                    x.append(line)
                self.result["CTProcesses"] = "\n".join(x)
                succeed = True
            except Exception as e:
                retries += 1
                time.sleep(60 * 2 * retries)
                succeed = False
                fail_reason = str(e)
        if not succeed:
            raise StandardError("Unable to collect ves info: " + fail_reason)


def main():
    o = VEs()
    o.run()


if __name__ == "__main__":
    main()
